@@ -632,45 +632,47 @@ void align_menu_callback(Fl_Widget *ob, void *unused)
 
 void cre_align_menu(SEA_VIEW *view, Fl_Menu_Button *obj)
 {
-char msa_name[60], *name; 
-int elt, attr;
-static const int clustalopt = UNALIGN + 2;//keep to rank in menu of first alignment option
+  char msa_name[60], *name; 
+  int elt, attr;
+  static const int clustalopt = UNALIGN + 2;//keep to rank in menu of first alignment option
 
-((Fl_Menu_Button*)obj)->add( "Align all", 0, align_menu_callback, (void *)&clustalopt, 0);
-((Fl_Menu_Button*)obj)->add( "Align selected sequences", 0, align_menu_callback, 0, 0);
-((Fl_Menu_Button*)obj)->add( "Align selected sites", 0, align_menu_callback, 0, 0);
-((Fl_Menu_Button*)obj)->add( "Profile alignment", 0, align_menu_callback, 0, FL_MENU_DIVIDER);
-((Fl_Menu_Button*)obj)->add( "De-align selection", 0, align_menu_callback, 0, FL_MENU_DIVIDER);
-obj->add("Alignment options", 0, 0, 0, FL_SUBMENU);
-for(elt = 1; elt <= MAX_MSA_ALGOS; elt++) {
-	sprintf(msa_name, "Alignment options/hidden_%d", elt);
-	attr = FL_MENU_RADIO; 
-	if(elt == view->count_msa_algos) attr |= FL_MENU_DIVIDER;
-	if(elt > view->count_msa_algos) attr |= FL_MENU_INVISIBLE;
-	attr = obj->add(msa_name, 0, align_opt_callback, (void *)&clustalopt, attr);
-	if(elt <= view->count_msa_algos) {
-		sprintf(msa_name, "msa_name_%d", elt);
-		name = get_res_value(msa_name, NULL);
-		obj->replace(clustalopt + elt - 1, name );
+  ((Fl_Menu_Button*)obj)->add( "Align all", 0, align_menu_callback, (void *)&clustalopt, 0);
+  ((Fl_Menu_Button*)obj)->add( "Align selected sequences", 0, align_menu_callback, 0, 0);
+  ((Fl_Menu_Button*)obj)->add( "Align selected sites", 0, align_menu_callback, 0, 0);
+  ((Fl_Menu_Button*)obj)->add( "Profile alignment", 0, align_menu_callback, 0, FL_MENU_DIVIDER);
+  ((Fl_Menu_Button*)obj)->add( "De-align selection", 0, align_menu_callback, 0, FL_MENU_DIVIDER);
+  obj->add("Alignment options", 0, 0, 0, FL_SUBMENU);
+  for(elt = 1; elt <= MAX_MSA_ALGOS; elt++) {
+    sprintf(msa_name, "Alignment options/hidden_%d", elt);
+    attr = FL_MENU_RADIO; 
+    if(elt == view->count_msa_algos) attr |= FL_MENU_DIVIDER;
+    if(elt > view->count_msa_algos) attr |= FL_MENU_INVISIBLE;
+    attr = obj->add(msa_name, 0, align_opt_callback, (void *)&clustalopt, attr);
+    if(elt <= view->count_msa_algos) {
+      sprintf(msa_name, "msa_name_%d", elt);
+      name = get_res_value(msa_name, NULL);
+      obj->replace(clustalopt + elt - 1, name );
 #ifndef WIN32
-		if(get_full_path(name) == NULL) {
-			attr = obj->mode(clustalopt + elt - 1);
-			obj->mode(clustalopt + elt - 1, attr | FL_MENU_INACTIVE);
-			} 
+      if(get_full_path(name) == NULL) {
+	attr = obj->mode(clustalopt + elt - 1);
+	obj->mode(clustalopt + elt - 1, attr | FL_MENU_INACTIVE);
+	} 
 #endif
-		}
-	}
-((Fl_Menu_Item *)obj->menu() + clustalopt + view->alignment_algorithm)->set();
-name = get_algo_opts(view->alignment_algorithm, NULL);
-sprintf(msa_name, "Alignment options/%s", name == NULL ? "<none>" : name);
-attr = FL_MENU_TOGGLE;
-if(name == NULL) attr |= FL_MENU_INACTIVE;
-obj->add(msa_name, 0, NULL, 0, attr);
-obj->add("Alignment options/Edit options", 0, edit_align_callback, (void *)&clustalopt, FL_MENU_DIVIDER);
-obj->add("Alignment options/Add external method", 0, add_align_w_callback, (void *)&clustalopt, 0);
-if(view->alignment_algorithm < 2) attr = FL_MENU_INACTIVE;
-else attr = 0;
-obj->add("Alignment options/Delete method", 0, delete_align_callback, (void *)&clustalopt, attr);
+      }
+    }
+  ((Fl_Menu_Item *)obj->menu() + clustalopt + view->alignment_algorithm)->set();
+  name = get_algo_opts(view->alignment_algorithm, NULL);
+  char *options = new char[100 + (name ? strlen(name) : 0) ];
+  sprintf(options, "Alignment options/%s", name == NULL ? "<none>" : name);
+  attr = FL_MENU_TOGGLE;
+  if(name == NULL) attr |= FL_MENU_INACTIVE;
+  obj->add(options, 0, NULL, 0, attr);
+  obj->add("Alignment options/Edit options", 0, edit_align_callback, (void *)&clustalopt, FL_MENU_DIVIDER);
+  obj->add("Alignment options/Add external method", 0, add_align_w_callback, (void *)&clustalopt, 0);
+  if(view->alignment_algorithm < 2) attr = FL_MENU_INACTIVE;
+  else attr = 0;
+  obj->add("Alignment options/Delete method", 0, delete_align_callback, (void *)&clustalopt, attr);
+  delete options;
 }
 
 
@@ -757,10 +759,11 @@ for(num = view->alignment_algorithm + 1; num <= view->count_msa_algos - 1; num++
 	name = get_opt_resname(num);
 	name = get_res_value(name, NULL);
 	if(name != NULL) {
-		strcpy(msa_name, name);
-		name = get_opt_resname(num - 1);
-		set_res_value(name, msa_name);
-		}
+	  char *tmp = strdup(name);
+	  name = get_opt_resname(num - 1);
+	  set_res_value(name, tmp);
+	  free(tmp);
+	  }
 	else delete_res_value(get_opt_resname(num - 1));
 	}
 sprintf(msa_name, "hidden_%d", view->count_msa_algos);
