@@ -4,6 +4,7 @@
 #include <FL/Fl_Slider.H>
 #include <FL/Fl_Check_Button.H>
 #include <FL/Fl_Value_Input.H>
+#include <FL/Fl_Int_Input.H>
 
 
 void custom_callback(Fl_Widget *obj, void *data);
@@ -26,6 +27,7 @@ static Fl_Slider *bgrnd, *s_bgrnd;
 static Fl_Input *protgroups, *s_protgroups, *movekeys;
 static Fl_Button **protcol;
 static Fl_Check_Button *lowercase, *inverted, *fastaspaces;
+static Fl_Int_Input *maxnamewidth;
 static Fl_Choice *pdfformat, *saveformat, *alignment_algo;
 static Fl_Value_Input *pdffontsize;
 static Fl_Value_Input *phylipwidnames;
@@ -47,6 +49,7 @@ extern int set_res_value(const char *name, const char *value);
 extern int save_resources(void);
 extern void minuscules(char *);
 extern char *get_res_value(const char *name, const char *def_value);
+extern int int_res_value(const char *name, int def_value);
 extern char aminoacids[]; // from misc_acnuc.c
 
 
@@ -184,7 +187,8 @@ if(win == NULL) {
   
 	y += inverted->h();
 	fastaspaces = new Fl_Check_Button(x,y,170,20, "spaces in FASTA names");
-	
+	fastaspaces->labelsize(13);
+
 	x = win->w() - w - 5;
 	y = movekeys->y() + movekeys->h() + 20;
 	
@@ -198,9 +202,14 @@ if(win == NULL) {
 	pdffontsize = new Fl_Value_Input(x+w/2,y,w/2,h, PDF_OR_PS" fontsize");
 	pdffontsize->align(FL_ALIGN_TOP_RIGHT);
 	pdffontsize->labelsize(10);
-	
+  
+	y += pdffontsize->h() + 15; 
+	maxnamewidth = new Fl_Int_Input(x, y, w, 20, "max name width");
+	maxnamewidth->labelsize(13);
+	maxnamewidth->align(FL_ALIGN_TOP);
+
 	x = A->x();
-	y = fastaspaces->y() + fastaspaces->h() + 20; 
+	y = fastaspaces->y() + fastaspaces->h() + 25; 
 	alignment_algo = new Fl_Choice(x,y,w,h, "alignment algorithm");
 	alignment_algo->align(FL_ALIGN_TOP);
   
@@ -208,6 +217,7 @@ if(win == NULL) {
 	x = pdfformat->x();
 	phylipwidnames = new Fl_Value_Input(x,y,w,h, "phylip names width");
 	phylipwidnames->align(FL_ALIGN_TOP);
+	phylipwidnames->labelsize(13);
 
 	x = A->x();
 	y += alignment_algo->h() + 10;
@@ -275,6 +285,7 @@ movekeys->value( view->movekeys );
 lowercase->value(view->allow_lower);
 inverted->value(view->inverted_colors);
 fastaspaces->value(view->spaces_in_fasta_names);
+maxnamewidth->value(get_res_value("maxnamewidth", "20"));
 pdfformat->value(printout_pageformat);
 pdffontsize->value(printout_fontsize);
 phylipwidnames->value(view->phylipwidnames);
@@ -370,6 +381,8 @@ if(view->inverted_colors) item->set();
 else item->clear();
   
 view->spaces_in_fasta_names = fastaspaces->value();
+  
+set_res_value("maxnamewidth", ((Fl_Input*)maxnamewidth)->value());
 
 printout_pageformat = (paperformat)pdfformat->value();
 printout_fontsize = (int)pdffontsize->value();
