@@ -39,7 +39,9 @@ Fl_Widget *cre_adjusted_button(int x, int y, int *w, int h,
 extern void hide_window_callback(Fl_Widget *ob, void *data);
 extern void allonge_seqs(char **seq, int totseqs, int maxlen, int *eachlength,
 	int tot_comment_lines, char **comment_line);
-	
+extern int compute_wid_names(SEA_VIEW *view, int totseqs);
+extern int compute_size_params(SEA_VIEW *view, int force_recompute);
+
 	
 void clear_callback(Fl_Widget *ob, void *data)
 {
@@ -381,6 +383,10 @@ view->tot_seqs = num;
 view->cursor_seq = num;
 view->cursor_site = 1;
 view->first_site = 1;
+if(strlen(view->seqname[num - 1]) > view->wid_names) {
+  view->wid_names = compute_wid_names(view, num);
+  compute_size_params(view, TRUE);
+}
 set_seaview_modified(view, TRUE);
 ((Fl_Slider*)view->horsli)->value(1);
 set_tot_lines(view, view->tot_lines);
