@@ -255,6 +255,13 @@ int run_external_prog_in_pseudoterm(char *cmd, const char *dialogfname, const ch
  */
 {
 	static struct listener_data data;
+	static bool inuse = 0;
+	if(inuse) {
+	  fl_alert("Operation %s is not possible while another alignment/tree-building is in progress",
+		   label);
+	  return 1;
+	  }
+	inuse = 1;
 	Fl_Window *w;
 #ifdef WIN32
 	HANDLE ChildInput, ChildStdoutRd, ChildStdoutWr, stdouthandle = NULL;
@@ -265,7 +272,10 @@ int run_external_prog_in_pseudoterm(char *cmd, const char *dialogfname, const ch
 	
 	if(dialogfname != NULL) {
 		FILE *in = fopen(dialogfname, "r");
-		if(in == NULL) return 1;
+		if(in == NULL) {
+		  inuse = 0;
+		  return 1;
+		  }
 		ChildInput = (HANDLE)_get_osfhandle(fileno(in));
 	}
 	p = cmd;//is there stdout redirection in cmd ?
@@ -307,8 +317,9 @@ int run_external_prog_in_pseudoterm(char *cmd, const char *dialogfname, const ch
 	if(stdouthandle != NULL) CloseHandle(stdouthandle);
 	if(dialogfname != NULL) CloseHandle(ChildInput);
 	if(retval == 0) {
-		CloseHandle(ChildStdoutRd);
-		return 1;
+	  CloseHandle(ChildStdoutRd);
+	  inuse = 0;
+	  return 1;
 	}
 	CloseHandle(pi.hThread);
 	w = create_and_run_pseudoterminal(label, &data, ChildStdoutRd, pi.hProcess);
@@ -319,17 +330,26 @@ int run_external_prog_in_pseudoterm(char *cmd, const char *dialogfname, const ch
 	//before Mac OS X 10.4, use openpty instead of posix_openpt that does not exist
 	int masterfd, slavefd;
 	char slavename[50];
-	if( openpty(&masterfd, &slavefd, slavename, NULL, NULL) == -1) return 1; 
+	if( openpty(&masterfd, &slavefd, slavename, NULL, NULL) == -1) {
+	  inuse = 0;
+	  return 1; 
+	  }
 	close(slavefd);
 #else
 	int masterfd = posix_openpt(O_RDWR|O_NOCTTY);
 	grantpt(masterfd);
 	unlockpt(masterfd);
 	char *slavename=ptsname(masterfd);
-	if(masterfd == -1 || slavename == NULL) return 1; 
+	if(masterfd == -1 || slavename == NULL) {
+	  inuse = 0;
+	  return 1;
+	  }
 #endif
 	pid_t pid = fork();
-	if(pid == -1) return 1;
+	if(pid == -1) {
+	  inuse = 0;
+	  return 1;
+	  }
 	else if(pid > 0) {// the parent
 		w = create_and_run_pseudoterminal(label, &data, masterfd, pid);
 	}
@@ -404,5 +424,6 @@ int run_external_prog_in_pseudoterm(char *cmd, const char *dialogfname, const ch
 	while(data.status == completed) Fl::wait();
 	delete w;
 	if(dialogfname != NULL) remove(dialogfname);
+	inuse = 0;
 	return data.status == aborted;
 } 
