@@ -45,6 +45,7 @@ extern void update_comment_gc(int seqnum, int ncbigc, SEA_VIEW *view);
 extern char *get_res_value(const char *name, const char *def_value);
 extern int set_res_value(const char *name, const char *value);
 extern void hide_window_callback(Fl_Widget *ob, void *data);
+extern int compute_wid_names(SEA_VIEW *view, int totseqs);
 extern "C" int get_ncbi_gc_number(int gc);
 
 /* globals */
@@ -57,7 +58,7 @@ return value: 0 iff OK
 */
 {
 raa_db_access *raa; 
-int err, num, length, truncated = FALSE;
+int err, length, truncated = FALSE;
 
 raa = open_acnuc_socket(w);
 if(raa == NULL) return 1;
@@ -90,9 +91,7 @@ else {
 	truncated = racnuc_fetch_file_or_list(listfile, 0, use_spec_name, raa, view);
 	}
 raa_acnucclose(raa);
-length = 0;
-for(num = 0; num < view->tot_seqs; num++) length = FL_max(length, strlen(view->seqname[num]));
-view->wid_names = FL_min(length, 20);
+view->wid_names = compute_wid_names(view, view->tot_seqs);
 compute_size_params(view, TRUE);
 view->DNA_obj->damage(FL_DAMAGE_ALL);
 view->horsli->damage(FL_DAMAGE_ALL);
