@@ -1,10 +1,12 @@
 #include "seaview.h"
 #include <FL/Fl_Round_Button.H>
+#include <ctype.h>
 
 
-enum position_mask {custom_mask = -1, position_1, position_2, position_3, position_12};
-const char *position_mask_names[4] = {"First codon pos.", "Second codon pos.",
-"Third codon pos.", "1st+2nd codon pos."};
+enum position_mask {custom_mask = -1, position_1, position_2, position_3, position_12,
+  variable_sites };
+const char *position_mask_names[5] = {"First codon pos.", "Second codon pos.",
+"Third codon pos.", "1st+2nd codon pos.", "Variable sites"};
 
 /* prototypes of included functions */
 region *duplicate_region(region *source, const char *name);
@@ -155,6 +157,39 @@ return TRUE;
 }
 
 
+void create_variable_mask(SEA_VIEW *view, region *maregion)
+{
+  int i, j, in_variable = FALSE;
+  list_segments *segment, *previous;
+  previous = NULL;
+ 
+  for(i = 1; i <= view->seq_length; i++) {
+    for (j = 1; j < view->tot_seqs; j++) {
+      if(toupper(view->sequence[j][i-1]) != toupper(view->sequence[0][i-1])) break;
+      }
+    if(j < view->tot_seqs) {
+      if(in_variable) continue;
+      in_variable = TRUE;
+      segment = (list_segments *)calloc(1, sizeof(list_segments));
+      segment->debut = i;
+      if(previous != NULL) previous->next = segment;
+      else maregion->list = segment;
+      previous = segment;
+    }
+    else {
+      if( ! in_variable) continue;
+      in_variable = FALSE;
+      segment->fin = i - 1;
+      for(j = segment->debut; j <= segment->fin; j++) view->region_line[j-1] = 'X';
+      }
+    }
+  if(in_variable) {
+    segment->fin = view->seq_length;
+    for(j = segment->debut; j <= segment->fin; j++) view->region_line[j-1] = 'X';
+    }
+}
+
+
 int create_codon_position_mask(SEA_VIEW *view, position_mask mask, const char *regname)
 {
   list_regions *old, *new_list;
@@ -169,29 +204,32 @@ int create_codon_position_mask(SEA_VIEW *view, position_mask mask, const char *r
   }
   maregion = (region *)calloc(1,sizeof(region));
   if(maregion ==  NULL) out_of_memory();
-  maregion->name = (char *)malloc(strlen(regname + 1));
+  maregion->name = (char *)malloc(strlen(regname) + 1);
   if(maregion->name ==  NULL) out_of_memory();
   strcpy(maregion->name, regname);
   
   memset(view->region_line, '-', view->seq_length);
-  previous = NULL;
-  for(i = 1; i <= view->seq_length; i += 3) {
-	segment = (list_segments *)calloc(1, sizeof(list_segments));
-	if(mask == position_12) {
-	  segment->debut = i;
-	  segment->fin = i + 1;
-	  view->region_line[i - 1] = 'X';
-	  view->region_line[i] = 'X';
-	}
-	else {
-	  segment->debut = i + mask;
-	  segment->fin = segment->debut;
-	  view->region_line[i - 1 + mask] = 'X';
-	}
-	if(previous != NULL) previous->next = segment;
-	else maregion->list = segment;
-	previous = segment;
-	}
+  if(mask < variable_sites) {
+    previous = NULL;
+    for(i = 1; i <= view->seq_length; i += 3) {
+      segment = (list_segments *)calloc(1, sizeof(list_segments));
+      if(mask == position_12) {
+	segment->debut = i;
+	segment->fin = i + 1;
+	view->region_line[i - 1] = 'X';
+	view->region_line[i] = 'X';
+      }
+      else {
+	segment->debut = i + mask;
+	segment->fin = segment->debut;
+	view->region_line[i - 1 + mask] = 'X';
+      }
+      if(previous != NULL) previous->next = segment;
+      else maregion->list = segment;
+      previous = segment;
+      }
+    }
+  else create_variable_mask(view, maregion);
   view->region_length = view->seq_length;
   view->region_line[view->region_length] = 0;
 
@@ -444,12 +482,12 @@ const char *site_mask_creation_dialog(SEA_VIEW *view, position_mask *outmask)
   const char *retval;
   static char custom_name[50];
   *outmask = custom_mask;
-  Fl_Window *w = new Fl_Window(300,180);
+  Fl_Window *w = new Fl_Window(300,200);
   w->label("Site set creation dialog");
   Fl_Input *input = new Fl_Input(180, 20, 100, 20, "Name of custom site set?");
   input->value("all sites");
-  Fl_Group  *g = new Fl_Group(0,25,w->w(),100);
-  Fl_Round_Button *mask[4];
+  Fl_Group  *g = new Fl_Group(0,25,w->w(),120);
+  Fl_Round_Button *mask[5];
   mask[0] = new Fl_Round_Button(30, input->y() + 30, 150, 20, position_mask_names[0]);
   mask[0]->type(FL_RADIO_BUTTON);
   mask[1] = new Fl_Round_Button(mask[0]->x(), mask[0]->y() + 20, 150, 20, position_mask_names[1]);
@@ -458,22 +496,27 @@ const char *site_mask_creation_dialog(SEA_VIEW *view, position_mask *outmask)
   mask[2]->type(FL_RADIO_BUTTON);
   mask[3] = new Fl_Round_Button(mask[0]->x(), mask[2]->y() + 20, 180, 20, position_mask_names[3]);
   mask[3]->type(FL_RADIO_BUTTON);
+  mask[4] = new Fl_Round_Button(mask[0]->x(), mask[3]->y() + 20, 120, 20, position_mask_names[4]);
+  mask[4]->type(FL_RADIO_BUTTON);
   g->end();
-  if(view->protein) g->deactivate();
-  Fl_Return_Button *ok = new Fl_Return_Button(170, mask[3]->y() + mask[3]->h() + 10, 50, 30, "Ok");
+  if(view->protein) {
+    for(int i = 0; i < 4; i++) mask[i]->deactivate();
+    }
+  Fl_Return_Button *ok = new Fl_Return_Button(170, mask[4]->y() + mask[4]->h() + 10, 50, 30, "Ok");
   Fl_Button *cancel = new Fl_Button(ok->x() + ok->w() + 5, ok->y(), 60, 30, "Cancel");
   w->end();
   w->show();
   while(TRUE) {
 	Fl_Widget *o = Fl::readqueue();
 	if (!o) Fl::wait();
-	else if(o == mask[0] || o == mask[1] || o == mask[2] || o == mask[3]) {
+	else if(o == mask[0] || o == mask[1] || o == mask[2] || o == mask[3] || o == mask[4]) {
 	  ((Fl_Round_Button*)o)->setonly();
 	  input->deactivate();
 	  if(o == mask[0]) {*outmask = position_1;}
 	  else if(o == mask[1]) {*outmask = position_2;}
 	  else if(o == mask[2]) {*outmask = position_3;}
-	  else {*outmask = position_12;}
+	  else if(o == mask[3]) {*outmask = position_12;}
+	  else {*outmask = variable_sites;}
 	  retval = position_mask_names[*outmask];
 	}
 	else if(o == cancel) {
