@@ -19,37 +19,44 @@ void delete_res_value(const char *name);
 /* for Mac OS X */
 char *get_res_value(const char *name, const char *def_value)
 {
-CFStringRef cfname;
-CFPropertyListRef cfvalue;
-static char value[200];
+  CFStringRef cfname;
+  CFPropertyListRef cfvalue;
+  static char value[400];
 
-cfname = CFStringCreateWithCString(kCFAllocatorDefault, name, kCFStringEncodingASCII);
-cfvalue = CFPreferencesCopyAppValue(cfname, kCFPreferencesCurrentApplication);
-if(cfvalue == NULL) return (char *)def_value;
-CFStringGetCString( (CFStringRef)cfvalue, value, sizeof(value), kCFStringEncodingASCII);
-CFRelease(cfname); CFRelease(cfvalue);
-return value;
+  cfname = CFStringCreateWithCString(kCFAllocatorDefault, name, kCFStringEncodingASCII);
+  if(cfname == NULL) return (char *)def_value;
+  cfvalue = CFPreferencesCopyAppValue(cfname, kCFPreferencesCurrentApplication);
+  CFRelease(cfname); 
+  if(cfvalue == NULL) return (char *)def_value;
+  Boolean ok = CFStringGetCString( (CFStringRef)cfvalue, value, sizeof(value), kCFStringEncodingASCII);
+  CFRelease(cfvalue);
+  return (ok ? value : (char *)def_value);
 }
 
 
 int set_res_value(const char *name, const char *value)
 {
-CFStringRef cfname, cfvalue;
+  CFStringRef cfname, cfvalue;
 
-cfname = CFStringCreateWithCString(kCFAllocatorDefault, name, kCFStringEncodingASCII);
-cfvalue = CFStringCreateWithCString(kCFAllocatorDefault, value, kCFStringEncodingASCII);
-CFPreferencesSetAppValue(cfname, cfvalue, kCFPreferencesCurrentApplication);
-CFPreferencesAppSynchronize(kCFPreferencesCurrentApplication);
-CFRelease(cfname); CFRelease(cfvalue);
-return 0;
+  cfname = CFStringCreateWithCString(kCFAllocatorDefault, name, kCFStringEncodingASCII);
+  if(cfname == NULL) return 1;
+  cfvalue = CFStringCreateWithCString(kCFAllocatorDefault, value, kCFStringEncodingASCII);
+  if(cfvalue == NULL) return 1;
+  CFPreferencesSetAppValue(cfname, cfvalue, kCFPreferencesCurrentApplication);
+  CFPreferencesAppSynchronize(kCFPreferencesCurrentApplication);
+  CFRelease(cfname); 
+  CFRelease(cfvalue);
+  return 0;
 }
 
 
 void delete_res_value(const char *name)
 {
-CFStringRef cfname;
-cfname = CFStringCreateWithCString(kCFAllocatorDefault, name, kCFStringEncodingASCII);
-CFPreferencesSetAppValue(cfname, NULL, kCFPreferencesCurrentApplication);
+  CFStringRef cfname;
+  cfname = CFStringCreateWithCString(kCFAllocatorDefault, name, kCFStringEncodingASCII);
+  if(cfname == NULL) return;
+  CFPreferencesSetAppValue(cfname, NULL, kCFPreferencesCurrentApplication);
+  CFRelease(cfname); 
 }
 
 
