@@ -16,7 +16,7 @@
 #include "FL/Fl_Choice.H"
 #include "FL/fl_draw.H"
 #include "FL/fl_ask.H"
-#include "FL/Fl_Native_File_Chooser.H"
+#include <FL/Fl_Native_File_Chooser.H>
 #ifndef FALSE
 #define FALSE 0
 #define TRUE (!FALSE)
@@ -44,6 +44,7 @@ extern "C" { char *my_fgets(char *s, int n, FILE *f); }
 
 #ifdef WIN32
 #include <wchar.h>
+#include <pdflib.h>
 typedef const wchar_t *LPCWSTR;
 extern char *wchartoutf8(LPCWSTR in);
 extern LPCWSTR utf8towchar(const char *in);
@@ -51,6 +52,10 @@ extern "C" {
 	void my_bell(void); 
 }
 #define fopen(a,b) _wfopen(utf8towchar(a), L##b)
+extern int win32_PDF_begin_document(PDF *p, const char *filename, int len, const char *optlist);
+extern void win32_PDF_end_document(PDF *p, const char *optlist);
+#define PDF_begin_document win32_PDF_begin_document
+#define PDF_end_document win32_PDF_end_document
 #define memccpy _memccpy
 #define fl_ringbell(a) my_bell()
 #elif defined __APPLE__
