@@ -47,6 +47,7 @@ typedef struct {
 	int notu;
 	int totbranches;
 	int has_br_length;
+	int lost_br_lengths;
 	int has_internal;
 	int root_num;
 	int rooted;
@@ -100,5 +101,6 @@ typedef struct {
 	Fl_Button *select_clade_button, *delete_clade_button, *complete_edit_button;
 	Fl_Counter *zoom;
 	Fl_Choice *root_unroot;
+	int page_count;
 } FD_nj_plot;
 #endif
