@@ -754,178 +754,187 @@ static void model_callback(Fl_Widget *ob, void *data)
 
 void run_phyml_callback(Fl_Widget *ob, void *data)
 {
-	SEA_VIEW *view = (SEA_VIEW *)data;
-	char input[PATH_MAX], base_fname[PATH_MAX], invar[10], alpha[10], *p;
-	int replicates, cats, status, seqlen, user_tree = FALSE, i;
-	float logL;
-	char **tmpseqs, **tmpnames;
-	
-	p = create_tmp_filename();
-	if(p == NULL) return;
-	strcpy(base_fname, p);
-	strcpy(input, base_fname);
-	strcat(input, ".phy");
-	region r, *pr = &r;
-	if(view->tot_sel_seqs > 0 && view->active_region == NULL) {
-		list_segments ls;
-		ls.debut = 1; ls.fin = view->seq_length; ls.next = NULL;
-		r.list = &ls;
-		}
-	else {
-		pr = view->active_region;
-		}
-	if(pr != NULL) {
-		list_segments *pls;
-		pls = pr->list;
-		seqlen = 0;
-		while(pls != NULL) {
-			seqlen += pls->fin - pls->debut + 1;
-			pls = pls->next;
-		}
-	}
-	else seqlen = view->seq_length;
-	//remove * from saved protein data
-	if(view->protein) {
-		tmpseqs = (char **)calloc(view->tot_seqs, sizeof(char *));
-		for( i = 0; i < view->tot_seqs; i++) {
-			if(view->tot_sel_seqs > 0 && !view->sel_seqs[i]) continue;
-			tmpseqs[i] = strdup(view->sequence[i]);
-			char *p = tmpseqs[i];
-			while((p = strchr(p, '*')) != NULL) *p = '-';
-			}
-		}
-	else tmpseqs = view->sequence;
-	//Use Seq##_ as sequence names
-	tmpnames = (char **)calloc(view->tot_seqs, sizeof(char *));
-	int length = 0;
-	for(i = 0; i < view->tot_seqs; i++) {
-		if(view->tot_sel_seqs > 0 && !view->sel_seqs[i]) continue;
-		tmpnames[i] = (char *)malloc(15);
-		sprintf(tmpnames[i], "Seq%d_", i);
-		length = FL_max(length, strlen(tmpnames[i]));
-		}
-	status = save_phylip_file(input, tmpseqs,
-					 tmpnames, view->tot_seqs, view->each_length, pr, 
-					 view->sel_seqs, view->tot_sel_seqs, length);
-	for(i = 0; i < view->tot_seqs; i++) if(tmpnames[i] != NULL) free(tmpnames[i]);
-	free(tmpnames);
-	if(view->protein) {
-		for( i = 0; i < view->tot_seqs; i++) {
-			if(tmpseqs[i] != NULL) free(tmpseqs[i]);
-			}
-		free(tmpseqs);
-		}
-	if(status) return;
-	if(b_alrt->value()) replicates = -4;
-	else if (b_no->value()) replicates = 0;
-	else sscanf(b_count->value(), "%d", &replicates);
-	if(i_no->value()) strcpy(invar, "0.0");
-	else if(i_estim->value()) strcpy(invar, "e");
-	else strcpy(invar, i_val->value());
-	if(g_no->value()) { cats = 1; strcpy(alpha, "2.0"); }
-	else {
-		sscanf(g_cats->mvalue()->label(), "%d", &cats);
-		if(a_est->value())  strcpy(alpha, "e");
-		else strcpy(alpha, a_val->value());
-		}
-	char modelname[20], *args;
-	strcpy(modelname, mymodel->mvalue()->label());
-	//build command line
-	args = (char *)malloc(1000);
-	sprintf(args, "%s -d %s -m %s -b %d -v %s -c %d -a %s",
-			phyml_path, view->protein?"aa":"nt", modelname, replicates, invar, cats, alpha); 
-	if( (!view->protein) && 
-	(strcmp(modelname,"K2P")==0 || strcmp(modelname,"HKY")==0 || strcmp(modelname,"F84")==0 || strcmp(modelname,"TN93")==0) ) {
-	if(r_estim->value()) {
-		strcat(args, " -t e");
-		}
-	else {
-		sprintf(args + strlen(args), " -t %s", r_val->value());
-		}
-	}
-	if(spr_b->value()) strcat(args, " -s SPR");
-	else if(nni_spr_b->value()) strcat(args, " -s BEST");
-	if(!u_optimize->value()) { strcat(args, " -o lr"); user_tree = TRUE; }
-	if(u_menutree->value()) {
-		 char *tree = view->trees[u_choice->value()];
-		 if(*tree == '[' && (p = strchr(tree, ']')) != NULL) { //remove tree header
-			 tree = p + 1;
-			 while(*tree == ' ') tree++;
-			 }
-		 tree = replace_tree_names_by_rank(tree, view->seqname, view->tot_seqs);
-		if(tree == NULL) {
-			fl_alert("Names in starting tree and alignment don't match.\nStarting tree will be ignored.");
-			}
-		else {
-			char tmp[PATH_MAX];
-			sprintf(tmp, "%s.startingtree", base_fname);
-			 FILE *out = fopen(tmp, "w");
-			 fputs(tree, out);
-			 free(tree);
-			 fclose(out);
-			 sprintf(args + strlen(args), " -u %s", tmp);
-			}
-	 }
-	if(u_random->value()) {
-			sprintf(args + strlen(args), " --rand_start --n_rand_starts %d", atoi(u_random_count->value()));
-			}
-	//finish with (long) input filename
-	sprintf(args + strlen(args), " -i %s", input);
-	ob->window()->hide(); //deletion of this window should be done totally at the end of this callback
-	status = run_external_prog_in_pseudoterm(args, NULL, "tree-building");
-	free(args);
-	remove(input);
-	sprintf(input, "%s.startingtree", base_fname);
-	remove(input);
-	sprintf(input, "%s.phy_phyml_stats.txt", base_fname);
-	FILE *in = fopen(input, "r");
-	logL = 0;
-	if(in != NULL) {//search tree likelihood
-		while(TRUE) {
-			char line[100];
-			p = fgets(line, sizeof(line), in);
-			if(p == NULL) break;
-			if( (p=strstr(line, "Log-likelihood:")) != NULL) sscanf(p+15, "%f", &logL);
-			}
-		fclose(in);
-		remove(input);
-		}
-	sprintf(input, "%s.phy_phyml_tree.txt", base_fname);
-	in = fopen(input, "r");
-	if( status != 0 || in == NULL ) {
-		if(in != NULL) fclose(in);
-		fl_message("%s: tree building cancelled", extract_filename(view->masename));
-		}
-	else {
-		char *display_tree;
-		fseek(in, 0, SEEK_END);
-		long l = ftell(in);
-		display_tree = (char *)malloc(l + 1);
-		int c; p = display_tree;
-		fseek(in, 0, SEEK_SET);
-		while( (c = getc(in)) != EOF) {
-			if(c != '\n' && c != '\r') *(p++) = c;
-			}
-		*p = 0;
-		fclose(in);
-		display_tree = put_names_back_in_tree(display_tree, view->seqname);
-		//clean tree internal labels
-		if(replicates > 0) display_tree = bootstrap_reformat(display_tree, replicates);
-		else if(replicates < 0) display_tree = alrt_reformat(display_tree);
-		//assemble tree description
-		char tree_label[100];
-		sprintf(tree_label, "PhyML ln(L)=%.1f %d sites %s", logL, seqlen, modelname);
-		if(replicates > 0) sprintf(tree_label + strlen(tree_label), " %d replic.", replicates);
-		if(cats > 1) sprintf(tree_label + strlen(tree_label), " %d rate classes", cats);
-		if(user_tree) strcat(tree_label, " User-tree");
-		//add label to tree
-		char *tree = (char *)malloc(strlen(tree_label) + strlen(display_tree) + 4);
-		sprintf(tree, "[%s] %s", tree_label, display_tree);
-		free(display_tree);
-		treedraw(tree, view, "PhyML_tree", FALSE);
-		}
-	remove(input);
-	Fl::delete_widget(ob->window());
+  FILE *in;
+  SEA_VIEW *view = (SEA_VIEW *)data;
+  char input[PATH_MAX], base_fname[PATH_MAX], invar[10], alpha[10], *p;
+  int replicates, cats, status, seqlen, user_tree = FALSE, i;
+  float logL;
+  char **tmpseqs, **tmpnames, **truenames;
+  
+  p = create_tmp_filename();
+  if(p == NULL) return;
+  strcpy(base_fname, p);
+  strcpy(input, base_fname);
+  strcat(input, ".phy");
+  region r, *pr = &r;
+  if(view->tot_sel_seqs > 0 && view->active_region == NULL) {
+	  list_segments ls;
+	  ls.debut = 1; ls.fin = view->seq_length; ls.next = NULL;
+	  r.list = &ls;
+	  }
+  else {
+	  pr = view->active_region;
+	  }
+  if(pr != NULL) {
+	  list_segments *pls;
+	  pls = pr->list;
+	  seqlen = 0;
+	  while(pls != NULL) {
+		  seqlen += pls->fin - pls->debut + 1;
+		  pls = pls->next;
+	  }
+  }
+  else seqlen = view->seq_length;
+  //remove * from saved protein data
+  if(view->protein) {
+	  tmpseqs = (char **)calloc(view->tot_seqs, sizeof(char *));
+	  for( i = 0; i < view->tot_seqs; i++) {
+		  if(view->tot_sel_seqs > 0 && !view->sel_seqs[i]) continue;
+		  tmpseqs[i] = strdup(view->sequence[i]);
+		  char *p = tmpseqs[i];
+		  while((p = strchr(p, '*')) != NULL) *p = '-';
+		  }
+	  }
+  else tmpseqs = view->sequence;
+  //Use Seq##_ as sequence names
+  tmpnames = (char **)calloc(view->tot_seqs, sizeof(char *));
+  //memorize seq names because can be changed while phyml runs
+  truenames = (char **)calloc(view->tot_seqs, sizeof(char *));
+  int length = 0;
+  for(i = 0; i < view->tot_seqs; i++) {
+    if(view->tot_sel_seqs > 0 && !view->sel_seqs[i]) continue;
+    tmpnames[i] = (char *)malloc(15);
+    truenames[i] = strdup(view->seqname[i]);
+    sprintf(tmpnames[i], "Seq%d_", i);
+    length = FL_max(length, strlen(tmpnames[i]));
+    }
+  status = save_phylip_file(input, tmpseqs,
+				   tmpnames, view->tot_seqs, view->each_length, pr, 
+				   view->sel_seqs, view->tot_sel_seqs, length);
+  for(i = 0; i < view->tot_seqs; i++) if(tmpnames[i] != NULL) free(tmpnames[i]);
+  free(tmpnames);
+  if(view->protein) {
+	  for( i = 0; i < view->tot_seqs; i++) {
+		  if(tmpseqs[i] != NULL) free(tmpseqs[i]);
+		  }
+	  free(tmpseqs);
+	  }
+  if(status) goto way_out;
+  if(b_alrt->value()) replicates = -4;
+  else if (b_no->value()) replicates = 0;
+  else sscanf(b_count->value(), "%d", &replicates);
+  if(i_no->value()) strcpy(invar, "0.0");
+  else if(i_estim->value()) strcpy(invar, "e");
+  else strcpy(invar, i_val->value());
+  if(g_no->value()) { cats = 1; strcpy(alpha, "2.0"); }
+  else {
+	  sscanf(g_cats->mvalue()->label(), "%d", &cats);
+	  if(a_est->value())  strcpy(alpha, "e");
+	  else strcpy(alpha, a_val->value());
+	  }
+  char modelname[20], *args;
+  strcpy(modelname, mymodel->mvalue()->label());
+  //build command line
+  args = (char *)malloc(1000);
+  sprintf(args, "%s -d %s -m %s -b %d -v %s -c %d -a %s",
+		  phyml_path, view->protein?"aa":"nt", modelname, replicates, invar, cats, alpha); 
+  if( (!view->protein) && 
+  (strcmp(modelname,"K2P")==0 || strcmp(modelname,"HKY")==0 || strcmp(modelname,"F84")==0 || strcmp(modelname,"TN93")==0) ) {
+  if(r_estim->value()) {
+	  strcat(args, " -t e");
+	  }
+  else {
+	  sprintf(args + strlen(args), " -t %s", r_val->value());
+	  }
+  }
+  if(spr_b->value()) strcat(args, " -s SPR");
+  else if(nni_spr_b->value()) strcat(args, " -s BEST");
+  if(!u_optimize->value()) { strcat(args, " -o lr"); user_tree = TRUE; }
+  if(u_menutree->value()) {
+	   char *tree = view->trees[u_choice->value()];
+	   if(*tree == '[' && (p = strchr(tree, ']')) != NULL) { //remove tree header
+		   tree = p + 1;
+		   while(*tree == ' ') tree++;
+		   }
+	   tree = replace_tree_names_by_rank(tree, view->seqname, view->tot_seqs);
+	  if(tree == NULL) {
+		  fl_alert("Names in starting tree and alignment don't match.\nStarting tree will be ignored.");
+		  }
+	  else {
+		  char tmp[PATH_MAX];
+		  sprintf(tmp, "%s.startingtree", base_fname);
+		   FILE *out = fopen(tmp, "w");
+		   fputs(tree, out);
+		   free(tree);
+		   fclose(out);
+		   sprintf(args + strlen(args), " -u %s", tmp);
+		  }
+   }
+  if(u_random->value()) {
+		  sprintf(args + strlen(args), " --rand_start --n_rand_starts %d", atoi(u_random_count->value()));
+		  }
+  //finish with (long) input filename
+  sprintf(args + strlen(args), " -i %s", input);
+  ob->window()->hide(); //deletion of this window should be done totally at the end of this callback
+  status = run_external_prog_in_pseudoterm(args, NULL, "tree-building");
+  free(args);
+  remove(input);
+  sprintf(input, "%s.startingtree", base_fname);
+  remove(input);
+  sprintf(input, "%s.phy_phyml_stats.txt", base_fname);
+  in = fopen(input, "r");
+  logL = 0;
+  if(in != NULL) {//search tree likelihood
+	  while(TRUE) {
+		  char line[100];
+		  p = fgets(line, sizeof(line), in);
+		  if(p == NULL) break;
+		  if( (p=strstr(line, "Log-likelihood:")) != NULL) sscanf(p+15, "%f", &logL);
+		  }
+	  fclose(in);
+	  remove(input);
+	  }
+  sprintf(input, "%s.phy_phyml_tree.txt", base_fname);
+  in = fopen(input, "r");
+  if( status != 0 || in == NULL ) {
+	  if(in != NULL) fclose(in);
+	  fl_message("%s: tree building cancelled", extract_filename(view->masename));
+	  }
+  else {
+	  char *display_tree;
+	  fseek(in, 0, SEEK_END);
+	  long l = ftell(in);
+	  display_tree = (char *)malloc(l + 1);
+	  int c; p = display_tree;
+	  fseek(in, 0, SEEK_SET);
+	  while( (c = getc(in)) != EOF) {
+		  if(c != '\n' && c != '\r') *(p++) = c;
+		  }
+	  *p = 0;
+	  fclose(in);
+	  display_tree = put_names_back_in_tree(display_tree, truenames);
+	  //clean tree internal labels
+	  if(replicates > 0) display_tree = bootstrap_reformat(display_tree, replicates);
+	  else if(replicates < 0) display_tree = alrt_reformat(display_tree);
+	  //assemble tree description
+	  char tree_label[100];
+	  sprintf(tree_label, "PhyML ln(L)=%.1f %d sites %s", logL, seqlen, modelname);
+	  if(replicates > 0) sprintf(tree_label + strlen(tree_label), " %d replic.", replicates);
+	  if(cats > 1) sprintf(tree_label + strlen(tree_label), " %d rate classes", cats);
+	  if(user_tree) strcat(tree_label, " User-tree");
+	  //add label to tree
+	  char *tree = (char *)malloc(strlen(tree_label) + strlen(display_tree) + 4);
+	  sprintf(tree, "[%s] %s", tree_label, display_tree);
+	  free(display_tree);
+	  treedraw(tree, view, "PhyML_tree", FALSE);
+	  }
+  remove(input);
+  Fl::delete_widget(ob->window());
+way_out:
+  for(i = 0; i < view->tot_seqs; i++) {
+    if(truenames[i]) free(truenames[i]);
+    }
+  free(truenames);
 }
 
 
