@@ -2,6 +2,9 @@
 #include <time.h>
 #include "unrooted.h"
 #include "treedraw.h"
+#if defined(MICRO)
+#include <FL/Fl_Printer.H>
+#endif
 
 
 /* prototypes of included functions */
@@ -87,13 +90,6 @@ extern int calc_brl_for_lengthless(struct noeud *centre, struct noeud *pere);
 extern const char *preptree(FD_nj_plot *fd_nj_plot);
 extern void free_tree(FD_nj_plot *fd_nj_plot);
 extern char *ecrit_arbre_parenth(FD_nj_plot *fd_nj_plot, struct noeud *root);
-#if defined(MICRO)
-extern int MG_StartPrinting (int pagecount, int *frompage, int *topage);
-extern int MG_StartPage (void);
-extern int MG_EndPage (void);
-extern void MG_EndPrinting (void);
-extern int MG_PrintingRect(int *x, int *y, int *w, int *h);
-#endif
 
 
 /* globals */
@@ -640,32 +636,34 @@ void pdf_unrooted(FD_unrooted *fd_unrooted, const char *name)
 #if defined(MICRO)
 void print_unrooted(FD_unrooted *fd_unrooted, const char *name)
 {
-	int from, to;
-	if( MG_StartPrinting(1, &from, &to) ) return;
-	fd_unrooted->previous_w = fd_unrooted->previous_h = 0;
-	MG_PrintingRect(&fd_unrooted->x, &fd_unrooted->y, &fd_unrooted->w, &fd_unrooted->h);
-	int old_x = fd_unrooted->x_offset;
-	int old_y = fd_unrooted->y_offset;
-	fd_unrooted->x_offset = fd_unrooted->y_offset = 0;
-	MG_StartPage();
-	fd_unrooted->y += 20;
-	fd_unrooted->h -= 20;
-	time_t heure;
-	time(&heure);
-	char bigline[200];
-	sprintf(bigline, "%s  %s", extract_filename(name), ctime(&heure));
-	fl_font(FL_TIMES, 12);
-	fl_color(FL_BLACK);
-	fl_draw(bigline, fd_unrooted->x, fd_unrooted->y - 5);
-	fl_color(FL_GRAY);
-	fl_rect(fd_unrooted->x, fd_unrooted->y, fd_unrooted->w, fd_unrooted->h);
-	fl_color(FL_BLACK);
-	fd_unrooted->comp_phys_bounds = TRUE;	
-	frame_and_draw_unrooted(fd_unrooted);
-	MG_EndPage();
-	MG_EndPrinting();
-	fd_unrooted->x_offset = old_x;
-	fd_unrooted->y_offset = old_y;
+  int from, to;
+  Fl_Printer myprinter;
+  if(myprinter.start_job(1, &from, &to) ) return;
+  fd_unrooted->previous_w = fd_unrooted->previous_h = 0;
+  myprinter.printable_rect( &fd_unrooted->w, &fd_unrooted->h);
+  fd_unrooted->x = fd_unrooted->y = 0;
+  int old_x = fd_unrooted->x_offset;
+  int old_y = fd_unrooted->y_offset;
+  fd_unrooted->x_offset = fd_unrooted->y_offset = 0;
+  myprinter.start_page();
+  fd_unrooted->y += 20;
+  fd_unrooted->h -= 20;
+  time_t heure;
+  time(&heure);
+  char bigline[200];
+  sprintf(bigline, "%s  %s", extract_filename(name), ctime(&heure));
+  fl_font(FL_TIMES, 12);
+  fl_color(FL_BLACK);
+  fl_draw(bigline, fd_unrooted->x, fd_unrooted->y - 5);
+  fl_color(FL_GRAY);
+  fl_rect(fd_unrooted->x, fd_unrooted->y, fd_unrooted->w, fd_unrooted->h);
+  fl_color(FL_BLACK);
+  fd_unrooted->comp_phys_bounds = TRUE;	
+  frame_and_draw_unrooted(fd_unrooted);
+  myprinter.end_page();
+  myprinter.end_job();
+  fd_unrooted->x_offset = old_x;
+  fd_unrooted->y_offset = old_y;
 }
 
 #endif
