@@ -1752,18 +1752,20 @@ return (p == s ? NULL : s);
 
 char *seaview_file_chooser_save_as(const char* message, const char* fname, SEA_VIEW *view)
 {
+#ifndef MICRO
+  const char *prev_label = Fl_File_Chooser::show_label;
+  Fl_File_Chooser::show_label = "Format";
+#endif
+
 char *p, types_list[500] = "";
 Fl_Native_File_Chooser *chooser = new Fl_Native_File_Chooser();
+#ifndef MICRO
+  Fl_File_Chooser::show_label = prev_label;
+#endif
+
 chooser->type(Fl_Native_File_Chooser::BROWSE_SAVE_FILE);   
 chooser->title(message);  
-chooser->preset_file(fname);  
-#ifndef MICRO
-	p = (char *)chooser->showChoice->label();
-	if(p != NULL && strcmp(p, Fl_File_Chooser::show_label) == 0) {
-	   chooser->showChoice->label("Format:");
-	   chooser->showChoice->labelsize( chooser->showChoice->labelsize() - 1);
-	   }
-#endif
+chooser->preset_file(fname); 
 	
 p = types_list;
 for(int f = 0; f < nbr_formats; f++) {
