@@ -70,38 +70,53 @@ if(onoff) { /* ON */
 		}
 	}
 else	{ /* OFF */
-	dnaseq = (char **)malloc(view->tot_seqs * sizeof(char *));
-	if(dnaseq == NULL) return view->viewasprots;
-	olddna = (char **)view->viewasprots;
-	for(num=0; num < view->tot_seqs; num++) {
-		dnaseq[num] = back_translate_with_gaps(view->sequence[num], olddna[num]);
-		if(dnaseq[num] == NULL) return view->viewasprots;
-		}
-	for(num=0; num < view->tot_seqs; num++) free(olddna[num]);
-	free(olddna);
-	for(num=0; num < view->tot_seqs; num++) free(view->sequence[num]);
-	free(view->sequence);
-	free(view->each_length);
-	view->sequence = dnaseq;
-	free_col_seqs(view);
-	if(view->region_line != NULL) free(view->region_line);
-	init_dna_scroller(view, view->tot_seqs, masename, FALSE, view->header);
-	set_and_show_new_cursor_site(view, 3*oldcursorsite, TRUE, FALSE);
-	if(view->regions != NULL) {
-		list_segments *lseg;
-		list_regions *lreg = view->regions;
-		while(lreg != NULL) {
-			lseg = lreg->element->list;
-			while(lseg != NULL) {
-				lseg->debut = 3*(lseg->debut - 1) + 1;
-				lseg->fin = 3*(lseg->fin);
-				lseg = lseg->next;
-				}
-			lreg = lreg->next;
-			}
-		}
-	retval = NULL;
+  int l, maxl = 0;
+  char *p;
+  dnaseq = (char **)malloc(view->tot_seqs * sizeof(char *));
+  if(dnaseq == NULL) return view->viewasprots;
+  olddna = (char **)view->viewasprots;
+  for(num=0; num < view->tot_seqs; num++) {
+    dnaseq[num] = back_translate_with_gaps(view->sequence[num], olddna[num]);
+    if(dnaseq[num] == NULL) return view->viewasprots;
+    l = view->each_length[num] = strlen(dnaseq[num]);
+    if(l > maxl) maxl = l;
+    }
+  maxl = 3*((maxl+2)/3); // desired alignment length as multiple of 3
+  for(num = 0; num < view->tot_seqs; num++) { // extend all seqs to maxl length with gaps
+    free(olddna[num]);
+    l = view->each_length[num];
+    if(l == maxl) continue;
+    p = (char *)realloc(dnaseq[num], maxl + 1);
+    if(p == NULL) continue;
+    dnaseq[num] = p;
+    p += l;
+    while(l++ < maxl) *(p++) = '-';
+    *p = 0;
+    }
+  free(olddna);
+  for(num=0; num < view->tot_seqs; num++) free(view->sequence[num]);
+  free(view->sequence);
+  free(view->each_length);
+  view->sequence = dnaseq;
+  free_col_seqs(view);
+  if(view->region_line != NULL) free(view->region_line);
+  init_dna_scroller(view, view->tot_seqs, masename, FALSE, view->header);
+  set_and_show_new_cursor_site(view, 3*oldcursorsite, TRUE, FALSE);
+  if(view->regions != NULL) {
+    list_segments *lseg;
+    list_regions *lreg = view->regions;
+    while(lreg != NULL) {
+      lseg = lreg->element->list;
+      while(lseg != NULL) {
+	lseg->debut = 3*(lseg->debut - 1) + 1;
+	lseg->fin = 3*(lseg->fin);
+	lseg = lseg->next;
 	}
+      lreg = lreg->next;
+      }
+    }
+  retval = NULL;
+  }
 set_seaview_modified(view, oldmodif);
 view->tot_sel_seqs = oldtotsel;
 set_and_show_new_cursor_seq(view, oldcursorseq);
@@ -170,9 +185,9 @@ char *back_translate_with_gaps(char *prot, char *dna)
 	*pd = 0;
 	while(memcmp(dna, "---", 3) == 0) dna += 3;
 	if(*dna != 0) {//if a partial codon remains at end
-		while(*(pd-1) == '-') pd--;
-		strcpy(pd, dna);
-		}
+	  while(*(pd-1) == '-') pd--;
+	  strcpy(pd, dna);
+	  }
 	return newdna;
 }
 
