@@ -11,6 +11,9 @@
 #include <direct.h>
 #include <stdlib.h>
 #include <stdio.h>
+#ifndef NO_PDF
+#include <pdflib.h>
+#endif
 
 /* included functions */
 void MG_fl_draw(const char *txt, int x, int y);
@@ -81,196 +84,6 @@ void MG_CompleteCopy(void *oldflgc)
 }
 
 
-static int   abortPrint;
-static PRINTDLG      pd;
-static HDC           hPr = NULL;
-static int           prerr;
-extern HWND fl_window;
-
-static void WIN_SetupPrinterDeviceContext(HDC prHDC)
-{
-	if ( !prHDC ) return;
-	
-	fl_window = 0;
-	fl_gc = prHDC;
-	SetMapMode(prHDC, MM_ANISOTROPIC);
-	SetTextAlign(prHDC, TA_BASELINE|TA_LEFT);
-	SetBkMode(prHDC, TRANSPARENT);	
-	HWND screenHwnd = GetDesktopWindow();
-	HDC  screenDC   = GetDC( screenHwnd );
-	
-	/* NOTE:  for video devices, the logical inch IS NOT == physical inch! */
-	SetWindowExtEx(prHDC, GetDeviceCaps(screenDC, LOGPIXELSX),
-				   GetDeviceCaps(screenDC, LOGPIXELSY), NULL);
-	SetViewportExtEx(prHDC, GetDeviceCaps(prHDC, LOGPIXELSX),
-					 GetDeviceCaps(prHDC, LOGPIXELSY), NULL);
-	
-	ReleaseDC(screenHwnd, screenDC);
-}
-
-
-int MG_StartPrinting (int pagecount, int *frompage, int *topage)
-// returns 0 iff OK
-{
-	DWORD       commdlgerr;
-	DOCINFO     di;
-	char        docName [256];
-	int err = 0;
-	
-	abortPrint = FALSE;
-	memset (&pd, 0, sizeof (PRINTDLG));
-	pd.lStructSize = sizeof (PRINTDLG);
-	pd.hwndOwner = GetForegroundWindow();
-	pd.Flags = PD_RETURNDC | PD_USEDEVMODECOPIESANDCOLLATE | PD_NOSELECTION;
-	pd.nMinPage = 1;
-	pd.nMaxPage = pagecount;
-	if (PrintDlg (&pd) != 0) {
-		hPr = pd.hDC;
-		if (hPr != NULL) {
-			WIN_SetupPrinterDeviceContext (hPr);
-			strcpy (docName, "Seaview");
-			memset(&di, 0, sizeof(DOCINFO));
-			di.cbSize = sizeof (DOCINFO);
-			di.lpszDocName = (LPCSTR) docName;
-			prerr = StartDoc (hPr, &di);
-			if (prerr < 1) {
-				abortPrint = TRUE;
-				fl_alert ("StartDoc error %d", prerr);
-				err = 1;
-			}
-		} else {
-			commdlgerr = CommDlgExtendedError ();
-			fl_alert ("Unable to create print context, error %lu",
-						 (unsigned long) commdlgerr);
-			err = 1;
-		}
-	} else {
-		err = 1;
-	}
-	if(!err) {
-		if((pd.Flags & PD_PAGENUMS) != 0 ) {
-			*frompage = pd.nFromPage;
-			*topage = pd.nToPage;
-			}
-		else {
-			*frompage = 1;
-			*topage = pagecount;
-			}
-		}
-	return err;
-}
-
-void MG_EndPrinting (void)
-{
-	if (hPr != NULL) {
-		if (! abortPrint) {
-			prerr = EndDoc (hPr);
-			if (prerr < 0) {
-				fl_alert ("EndDoc error %d", prerr);
-			}
-		}
-		DeleteDC (hPr);
-		if (pd.hDevMode != NULL) {
-			GlobalFree (pd.hDevMode);
-		}
-		if (pd.hDevNames != NULL) {
-			GlobalFree (pd.hDevNames);
-		}
-	}
-}
-
-
-int MG_ClipPrintingRect(int x, int y, int w, int h)
-{
-	long left, right, top, bottom;
-	POINT    pt;
-		
-	left = x - 1; right = x + w;
-	top = y - 1; bottom = y + h ;
-	
-	if (hPr == NULL) return FALSE;
-	
-	pt.x = left;
-	pt.y = bottom;
-	LPtoDP(hPr, &pt, 1);
-	left   = pt.x;
-	bottom = pt.y;
-	
-	pt.x = right;
-	pt.y = top;
-	LPtoDP(hPr, &pt, 1);
-	right = pt.x;
-	top   = pt.y;
-	
-    HRGN hRgnClip = CreateRectRgn (left, top, right, bottom);
-    SelectClipRgn (hPr, hRgnClip);
-    DeleteObject (hRgnClip);
-	return TRUE;
-}
-
-
-int MG_PrintingRect(int *x, int *y, int *w, int *h)
-{
-	POINT         physPageSize;
-	POINT         pixelsPerInch;
-		
-	*x = *y = 0;
-	
-	if (hPr == NULL) return FALSE;
-	
-	physPageSize.x = GetDeviceCaps(hPr, HORZRES);
-	physPageSize.y = GetDeviceCaps(hPr, VERTRES);
-	DPtoLP(hPr, &physPageSize, 1);
-	*w = physPageSize.x - *x + 1;
-	*h = physPageSize.y - *y + 1;
-	pixelsPerInch.x = GetDeviceCaps(hPr, LOGPIXELSX);
-	pixelsPerInch.y = GetDeviceCaps(hPr, LOGPIXELSY);
-	DPtoLP(hPr, &pixelsPerInch, 1);
-	*x += (pixelsPerInch.x / 4);
-	*w -= (pixelsPerInch.x / 2);
-	*y += (pixelsPerInch.y / 4);
-	*h -= (pixelsPerInch.y / 2);
-
-	return TRUE;
-}
-
-int MG_StartPage (void)
-{
-	int  rsult;
-	
-	rsult = TRUE;
-	if (hPr != NULL) {
-		WIN_SetupPrinterDeviceContext (hPr);
-		prerr = StartPage (hPr);
-		if (prerr < 0) {
-			fl_alert ("StartPage error %d", prerr);
-			rsult = FALSE;
-		}
-		fl_window = 0;
-		fl_gc = hPr;
-	}
-	return rsult;
-}
-
-int MG_EndPage (void)
-{
-	int  rsult;
-	
-	rsult = TRUE;
-	if (hPr != NULL) {
-		prerr = EndPage (hPr);
-		if (prerr < 0) {
-			abortPrint = TRUE;
-			fl_alert ("EndPage error %d", prerr);
-			rsult = FALSE;
-		}
-	} else {
-		rsult = FALSE;
-	}
-	return rsult;
-}
-
-
 int mysystem(const char *command)
 /*
  command contains "cmd.exe /c prog.exe args"  or  "prog.exe args"
@@ -373,6 +186,29 @@ void draw_rotated_string(const char *strDraw, int x, int y, float degrees /*cloc
 	delete wout;
 }
 
+extern LPCWSTR utf8towchar(const char *in);
+static FILE *pdf_output = NULL;
+
+static size_t pdf_write_proc(PDF *p, void *data, size_t size)
+{
+  return fwrite(data, 1, size, pdf_output);
+}
+
+// because PDF_begin_document fails on WIN32 if non ascii filename
+int win32_PDF_begin_document(PDF *p, const char *filename, int len, const char *optlist)
+{
+  pdf_output = _wfopen(utf8towchar(filename), L"wb"); // binary mode compulsory
+  if(pdf_output == NULL) return -1;
+  PDF_begin_document_callback(p, pdf_write_proc, optlist);
+  return 1;
+}
+
+void win32_PDF_end_document(PDF *p, const char *optlist)
+{
+  PDF_end_document(p, optlist);
+  fclose(pdf_output);
+  pdf_output = NULL;
+}
 
 /*
  void add_to_path(char *dir)
